package PiTube::Controller::Record;
use Mojo::Base 'Mojolicious::Controller';

use constant PAGE_SIZE => 5;
use constant SORT_COLUMNS => qr/stream_name|publish_user_name|begin/;
use constant SORT_DIRS    => qr/asc|desc/;

sub list {
    my $c = shift;

    my $readable = $c->schema->resultset('ACL')->user_acl(
        $c->session->{user}, 4
    );

    my $cond = {
        is_active => 't',
        -or => [
            { stream_is_public => 't' },
            { stream_key => { -in => $readable }},
        ]
    };

    my $count = $c->schema->resultset('Record_view')->count($cond);

    my $sort = { -desc => 'begin' };

    if ( $c->param('sort') =~ SORT_COLUMNS && $c->param('order') =~ SORT_DIRS ) {
        $sort = { '-' . $c->param('order') => $c->param('sort') };
    }

    my $records = $c->schema->resultset('Record_view')->search(
        $cond,
        {
            order_by => $sort,
            offset   => $c->param('offset') // 0,
            rows     => $c->param('limit') // PAGE_SIZE,
        }
    );

    my @records = ();

    RECORD:
    while ( my $record = $records->next()) {

        my %record = (
            $record->get_columns(),
            is_deletable => $record->is_deletable( $c->session->{user}{id} ),
        );

        push @records, \%record;
    }

    $c->render( json => {
        total => $count,
        rows  => \@records,
    });
}

sub player {
    my $c = shift;

    # vzdy aktualizovat
    $c->session->{user}{acl} = $c->schema->resultset('ACL')->user_acl(
        $c->session->{user}
    );

    # record
    my $record = $c->schema->resultset('Record_view')->find({
        id => $c->stash->{id}
    });

    if ( ! $record ) {
        $c->render('record/404');
        return;
    }

    $c->stash->{record} = {
        $record->get_columns,
    };

    if ( ! ( $c->session->{user}{acl}{ $record->stream_key } & 4 ) ) { # TODO:constant
        $c->render('record/403');
        return;
    }

    $c->render();
}

sub delete {
    my $c = shift;

    my $record = $c->schema->resultset('Record')->search({
        id              => $c->stash->{id},
        is_protected    => 'f',
        publish_user_id => $c->session->{user}{id}
    })->first;

    if ( ! $record ) {
        $c->render( status => 404, text => '');
        return;
    }

    $record->update({
        is_active => 'f'
    });

    $c->render( status => 204, text => '' );
}

1;
