-- 1 up
create sequence "uid_seq" start 100000;

create table "users" (
    "id" integer not null default nextval('uid_seq'),
    "uuid" varchar(36) not null,
    "username" text,
    "name" text,
    "token" text,
    primary key("id"),
    unique("uuid"),
    unique("token")
);

create table "streams" (
    "id" integer not null default nextval('uid_seq'),
    "is_active" bool not null default true,
    "is_public" bool not null default true,
    "key" text,
    "name" text,
    "publish_user_id" integer,
    "publish_last" timestamp(0),
    "publish_time" integer,
    primary key("id"),
    unique("key")
);

create table "acl" (
    "id" integer not null default nextval('uid_seq'),
    "stream_id" integer not null,
    "rights" smallint, -- 4 - play, 2 - push, 1 - admin
    "class" text,
    "value" text,
    primary key("id"),
    foreign key ("stream_id") references "streams" ("id") on update cascade on delete cascade
);

create view "streams_view" as
select "streams".*,
    extract(epoch from now()-"publish_last") as "publish_last_age",
    "users"."name" as "publish_user_name"
from "streams"
left join "users" on ("streams"."publish_user_id" = "users"."id")
;

-- 1 down
drop view "streams_view";
drop table "acl";
drop table "streams";
drop table "users";
drop sequence "uid_seq";

-- 2 up
alter table "streams" add "description" text;

-- 3 up
drop view "streams_view";
alter table "streams" add "recording" bool null default false;
create view "streams_view" as
select "streams".*,
    extract(epoch from now()-"publish_last") as "publish_last_age",
    "users"."name" as "publish_user_name"
from "streams"
left join "users" on ("streams"."publish_user_id" = "users"."id")
;

-- 4 up
create table "records" (
    "id" integer not null default nextval('uid_seq'),
    "begin" timestamp(0) not null default now(),
    "end" timestamp(0),
    "is_active" bool not null default true,
    "is_protected" bool not null default false,
    "stream_id" integer not null,
    "publish_user_id" integer not null,
    "recorder" text,
    "path" text,
    "description" text,
    "info" text,
    primary key("id"),
    foreign key ("stream_id") references "streams" ("id") on update cascade on delete restrict,
    foreign key ("publish_user_id") references "users" ("id") on update cascade on delete restrict
);

-- 5 up

create view "records_view" as
select "records".*,
    "streams"."key" as "stream_key",
    "streams"."name" as "stream_name",
    "streams"."is_public" as "stream_is_public",
    "users"."name" as "publish_user_name"
from "records"
left join "users" on ("records"."publish_user_id" = "users"."id")
join "streams" on ("records"."stream_id" = "streams"."id")
;
